@@ -13,9 +13,9 @@
 ## |
 ## |  Contact us for information about our services: info@rpact.com
 ## |
-## |  File version: $Revision: 5684 $
-## |  Last changed: $Date: 2022-01-05 12:27:24 +0100 (Mi, 05 Jan 2022) $
-## |  Last changed by: $Author: wassmer $
+## |  File version: $Revision: 6139 $
+## |  Last changed: $Date: 2022-05-10 14:45:01 +0200 (Tue, 10 May 2022) $
+## |  Last changed by: $Author: pahlke $
 ## |
 
 .getAnalysisResultsSurvival <- function(..., design, dataInput) {
@@ -263,9 +263,8 @@
         # final confidence interval & median unbiased estimate
         startTime <- Sys.time()
         finalConfidenceIntervals <- .getFinalConfidenceIntervalSurvival(
-            design = design,
-            dataInput = dataInput, thetaH0 = thetaH0, stage = stage, directionUpper = directionUpper,
-            tolerance = tolerance
+            design = design, dataInput = dataInput, thetaH0 = thetaH0, stage = stage, 
+            directionUpper = directionUpper, tolerance = tolerance
         )
 
         if (!is.null(finalConfidenceIntervals)) {
@@ -499,61 +498,63 @@
     repeatedConfidenceIntervals <- matrix(NA_real_, 2, design$kMax)
     for (k in (1:stage)) {
         startTime <- Sys.time()
-
-        # Finding maximum upper and minimum lower bounds for RCIs
-        thetaLow <- exp(.getUpperLowerThetaSurvival(
-            design = design, dataInput = dataInput,
-            theta = -1, stage = k, directionUpper = TRUE,
-            conditionFunction = conditionFunction, firstParameterName = firstParameterName,
-            secondValue = criticalValues[k]
-        ))
-
-        thetaUp <- exp(.getUpperLowerThetaSurvival(
-            design = design, dataInput = dataInput,
-            theta = 1, stage = k, directionUpper = FALSE,
-            conditionFunction = conditionFunction, firstParameterName = firstParameterName,
-            secondValue = criticalValues[k]
-        ))
-
-        # Finding upper and lower RCI limits through root function
-        repeatedConfidenceIntervals[1, k] <- .getRootThetaSurvival(
-            design = design, dataInput = dataInput, stage = k, directionUpper = C_DIRECTION_UPPER_DEFAULT,
-            thetaLow = thetaLow, thetaUp = thetaUp, firstParameterName = firstParameterName,
-            secondValue = criticalValues[k], tolerance = tolerance,
-            callingFunctionInformation = paste0("Repeated confidence interval [1, ", k, "]")
-        )
-
-        repeatedConfidenceIntervals[2, k] <- .getRootThetaSurvival(
-            design = design, dataInput = dataInput, stage = k, directionUpper = FALSE,
-            thetaLow = thetaLow, thetaUp = thetaUp, firstParameterName = firstParameterName,
-            secondValue = criticalValues[k], tolerance = tolerance,
-            callingFunctionInformation = paste0("Repeated confidence interval [2, ", k, "]")
-        )
-
-        # Adjustment for binding futility bounds
-        if (k > 1 && conditionFunction(bounds[k - 1], border) & design$bindingFutility) {
-            parameterName <- ifelse(.isTrialDesignFisher(design), "pValues", firstParameterName)
-
-            futilityCorr[k] <- .getRootThetaSurvival(
-                design = design, dataInput = dataInput, stage = k - 1, directionUpper = directionUpper,
-                thetaLow = thetaLow, thetaUp = thetaUp,
-                firstParameterName = parameterName, secondValue = bounds[k - 1], tolerance = tolerance,
-                callingFunctionInformation = paste0("Repeated confidence interval, futility correction [", k, "]")
-            )
-
-            if (directionUpper) {
-                repeatedConfidenceIntervals[1, k] <- min(min(futilityCorr[2:k]), repeatedConfidenceIntervals[1, k])
-            } else {
-                repeatedConfidenceIntervals[2, k] <- max(max(futilityCorr[2:k]), repeatedConfidenceIntervals[2, k])
-            }
-        }
-        .logProgress("Repeated confidence interval of stage %s calculated", startTime = startTime, k)
-
-        if (!is.na(repeatedConfidenceIntervals[1, k]) && !is.na(repeatedConfidenceIntervals[2, k]) &&
-                repeatedConfidenceIntervals[1, k] > repeatedConfidenceIntervals[2, k]) {
-            repeatedConfidenceIntervals[, k] <- rep(NA_real_, 2)
-        }
-    }
+		if (criticalValues[k] < C_QNORM_MAXIMUM) {		
+		
+	        # Finding maximum upper and minimum lower bounds for RCIs
+	        thetaLow <- exp(.getUpperLowerThetaSurvival(
+	            design = design, dataInput = dataInput,
+	            theta = -1, stage = k, directionUpper = TRUE,
+	            conditionFunction = conditionFunction, firstParameterName = firstParameterName,
+	            secondValue = criticalValues[k]
+	        ))
+	
+	        thetaUp <- exp(.getUpperLowerThetaSurvival(
+	            design = design, dataInput = dataInput,
+	            theta = 1, stage = k, directionUpper = FALSE,
+	            conditionFunction = conditionFunction, firstParameterName = firstParameterName,
+	            secondValue = criticalValues[k]
+	        ))
+	
+	        # Finding upper and lower RCI limits through root function
+	        repeatedConfidenceIntervals[1, k] <- .getRootThetaSurvival(
+	            design = design, dataInput = dataInput, stage = k, directionUpper = C_DIRECTION_UPPER_DEFAULT,
+	            thetaLow = thetaLow, thetaUp = thetaUp, firstParameterName = firstParameterName,
+	            secondValue = criticalValues[k], tolerance = tolerance,
+	            callingFunctionInformation = paste0("Repeated confidence interval [1, ", k, "]")
+	        )
+	
+	        repeatedConfidenceIntervals[2, k] <- .getRootThetaSurvival(
+	            design = design, dataInput = dataInput, stage = k, directionUpper = FALSE,
+	            thetaLow = thetaLow, thetaUp = thetaUp, firstParameterName = firstParameterName,
+	            secondValue = criticalValues[k], tolerance = tolerance,
+	            callingFunctionInformation = paste0("Repeated confidence interval [2, ", k, "]")
+	        )
+	
+	        # Adjustment for binding futility bounds
+			if (k > 1 && !is.na(bounds[k - 1]) && conditionFunction(bounds[k - 1], border) && design$bindingFutility) {		
+	            parameterName <- ifelse(.isTrialDesignFisher(design), "pValues", firstParameterName)
+	
+	            futilityCorr[k] <- .getRootThetaSurvival(
+	                design = design, dataInput = dataInput, stage = k - 1, directionUpper = directionUpper,
+	                thetaLow = thetaLow, thetaUp = thetaUp,
+	                firstParameterName = parameterName, secondValue = bounds[k - 1], tolerance = tolerance,
+	                callingFunctionInformation = paste0("Repeated confidence interval, futility correction [", k, "]")
+	            )
+	
+	            if (directionUpper) {
+	                repeatedConfidenceIntervals[1, k] <- min(min(futilityCorr[2:k]), repeatedConfidenceIntervals[1, k])
+	            } else {
+	                repeatedConfidenceIntervals[2, k] <- max(max(futilityCorr[2:k]), repeatedConfidenceIntervals[2, k])
+	            }
+	        }
+	        .logProgress("Repeated confidence interval of stage %s calculated", startTime = startTime, k)
+	
+	        if (!is.na(repeatedConfidenceIntervals[1, k]) && !is.na(repeatedConfidenceIntervals[2, k]) &&
+	                repeatedConfidenceIntervals[1, k] > repeatedConfidenceIntervals[2, k]) {
+	            repeatedConfidenceIntervals[, k] <- rep(NA_real_, 2)
+	        }
+	    }
+	}	
 
     return(repeatedConfidenceIntervals)
 }
@@ -1061,7 +1062,7 @@
     stageResults <- .getStageResultsSurvival(
         design = design, dataInput = dataInput, stage = stage,
         thetaH0 = thetaH0, directionUpper = directionUpper
-    )
+    )    
 
     finalConfidenceIntervalGeneral <- rep(NA_real_, 2)
     medianUnbiasedGeneral <- NA_real_
@@ -1149,6 +1150,10 @@
     }
 
     return(list(
+        stage = stage,
+        thetaH0 = thetaH0, 
+        directionUpper = directionUpper,
+        tolerance = tolerance,            
         finalStage = finalStage,
         medianUnbiasedGeneral = medianUnbiasedGeneral,
         finalConfidenceIntervalGeneral = sort(finalConfidenceIntervalGeneral),
@@ -1258,6 +1263,10 @@
     }
 
     return(list(
+        stage = stage,
+        thetaH0 = thetaH0, 
+        directionUpper = directionUpper,
+        tolerance = tolerance,            
         finalStage = finalStage,
         medianUnbiasedGeneral = medianUnbiasedGeneral,
         finalConfidenceIntervalGeneral = sort(finalConfidenceIntervalGeneral),
@@ -1298,6 +1307,10 @@
     }
 
     return(list(
+        stage = stage,
+        thetaH0 = thetaH0, 
+        directionUpper = directionUpper,
+        tolerance = tolerance,            
         finalStage = finalStage,
         medianUnbiased = medianUnbiased,
         finalConfidenceInterval = finalConfidenceInterval
